==> qgo_1.0.0-r2.orig.tar.gz: qgo-1.0.0/src/icons.h <==
/*
 * icons.h
 */

#ifndef ICONS_H
#define ICONS_H

#define USE_XPM  
//#undef USE_XPM

#ifdef USE_XPM
#define WOOD_PIC "./pics/wood.xpm"
#define WOOD2_PIC "./pics/wood2.xpm"
#define WOOD3_PIC "./pics/wood3.xpm"
#define WOOD4_PIC "./pics/wood4.xpm"
#define WOOD5_PIC "./pics/wood5.xpm"
#define TABLE_PIC "./pics/table.xpm"
#define ICON_PREFS "./pics/package_settings.xpm"
#define ICON_GAMEINFO "./pics/idea.xpm"
#define ICON_TELNET "./pics/openterm.xpm"
#define ICON_EXIT "./pics/exit.xpm"
#define ICON_FILENEWBOARD "./pics/newboard.xpm"
#define ICON_FILENEW "./pics/filenew.xpm"
#define ICON_FILEOPEN "./pics/fileopen.xpm"
#define ICON_FILESAVE "./pics/filesave.xpm"
#define ICON_FILESAVEAS "./pics/filesaveas.xpm"
#define ICON_TRANSFORM "./pics/transform.xpm"
#define ICON_CHARSET "./pics/charset.xpm"
#define ICON_RIGHTARROW "./pics/1rightarrow.xpm"
#define ICON_LEFTARROW "./pics/1leftarrow.xpm"
#define ICON_RIGHTCOMMENT "./pics/1rightcomment.xpm"        //added eb 2
#define ICON_LEFTCOMMENT "./pics/1leftcomment.xpm"          // end add eb 2
#define ICON_TWO_RIGHTARROW "./pics/2rightarrow.xpm"
#define ICON_TWO_LEFTARROW "./pics/2leftarrow.xpm"
#define ICON_NEXT_VAR "./pics/down.xpm"
#define ICON_PREV_VAR "./pics/up.xpm"
#define ICON_MAIN_BRANCH "./pics/start.xpm"
#define ICON_START_VAR "./pics/top.xpm"
#define ICON_NEXT_BRANCH "./pics/bottom.xpm"
#define ICON_AUTOPLAY "./pics/player_pause.xpm"
#define ICON_CUT "./pics/editcut.xpm"
#define ICON_PASTE "./pics/editpaste.xpm"
#define ICON_DELETE "./pics/editdelete.xpm"
#define ICON_INCREASE_SIZE "./pics/viewmag+.xpm"
#define ICON_DECREASE_SIZE "./pics/viewmag-.xpm"
#define ICON_FULLSCREEN "./pics/window_fullscreen.xpm"
#define ICON_WHATSTHIS "./pics/contexthelp.xpm"
#define ICON_MANUAL "./pics/help.xpm"
#define ICON_HOME "./pics/gohome.xpm"
#define ICON_APPICON "./pics/Bowl.xpm"
#define ICON_NODE_BLACK "./pics/node_black.xpm"
#define ICON_NODE_WHITE "./pics/node_white.xpm"
#define ALT_GHOST_BLACK "./pics/alt_ghost_black.xpm"
#define ALT_GHOST_WHITE "./pics/alt_ghost_white.xpm"
#define ICON_CONNECTED "./pics/connected.xpm"             
#define ICON_DISCONNECTED "./pics/connect_no.xpm"         
#define ICON_OPEN "./pics/open.xpm"			
#define ICON_LOOKING "./pics/looking.xpm"
#define ICON_QUIET "./pics/quiet.xpm"
#define ICON_NOT_OPEN "./pics/not_open.xpm"
#define ICON_NOT_LOOKING "./pics/not_looking.xpm"
#define ICON_NOT_QUIET "./pics/not_quiet.xpm"
#define ICON_REFRESH_PLAYERS "./pics/refresh_players.xpm"   //added eb 6
#define ICON_REFRESH_GAMES "./pics/refresh_games.xpm"       //end add eb 6
#define ICON_NAV_INTERSECTION "./pics/navIntersection.xpm"       //SL added eb 11
#define ICON_COMPUTER_PLAY "./pics/computerplay.xpm"       //SL added eb 12


#else 
#define WOOD_PIC "./pics/wood.png"
#define WOOD2_PIC "./pics/wood2.png"
#define WOOD3_PIC "./pics/wood3.png"
#define WOOD4_PIC "./pics/wood4.png"
#define WOOD5_PIC "./pics/wood5.png"
#define TABLE_PIC "./pics/table.png"
#define ICON_PREFS "./pics/package_settings.png"
#define ICON_GAMEINFO "./pics/idea.png"
#define ICON_TELNET "./pics/openterm.png"
#define ICON_EXIT "./pics/exit.png"
#define ICON_FILENEWBOARD "./pics/newboard.png"
#define ICON_FILENEW "./pics/filenew.png"
#define ICON_FILEOPEN "./pics/fileopen.png"
#define ICON_FILESAVE "./pics/filesave.png"
#define ICON_FILESAVEAS "./pics/filesaveas.png"
#define ICON_TRANSFORM "./pics/transform.png"
#define ICON_CHARSET "./pics/charset.png"
#define ICON_RIGHTARROW "./pics/1rightarrow.png"
#define ICON_LEFTARROW "./pics/1leftarrow.png"
#define ICON_RIGHTCOMMENT "./pics/1rightcomment.png"        
#define ICON_LEFTCOMMENT "./pics/1leftcomment.png"         
#define ICON_TWO_RIGHTARROW "./pics/2rightarrow.png"
#define ICON_TWO_LEFTARROW "./pics/2leftarrow.png"
#define ICON_NEXT_VAR "./pics/down.png"
#define ICON_PREV_VAR "./pics/up.png"
#define ICON_MAIN_BRANCH "./pics/start.png"
#define ICON_START_VAR "./pics/top.png"
#define ICON_NEXT_BRANCH "./pics/bottom.png"
#define ICON_AUTOPLAY "./pics/player_pause.png"
#define ICON_CUT "./pics/editcut.png"
#define ICON_PASTE "./pics/editpaste.png"
#define ICON_DELETE "./pics/editdelete.png"
#define ICON_INCREASE_SIZE "./pics/viewmag+.png"
#define ICON_DECREASE_SIZE "./pics/viewmag-.png"
#define ICON_FULLSCREEN "./pics/window_fullscreen.png"
#define ICON_WHATSTHIS "./pics/contexthelp.png"
#define ICON_MANUAL "./pics/help.png"
#define ICON_HOME "./pics/gohome.png"
#define ICON_APPICON "./pics/Bowl.png"
#define ICON_NODE_BLACK "./pics/node_black.png"
#define ICON_NODE_WHITE "./pics/node_white.png"
#define ALT_GHOST_BLACK "./pics/alt_ghost_black.png"
#define ALT_GHOST_WHITE "./pics/alt_ghost_white.png"
#define ICON_CONNECTED "./pics/connected.png"             
#define ICON_DISCONNECTED "./pics/connect_no.png"         
#define ICON_OPEN "./pics/open.png"			
#define ICON_LOOKING "./pics/looking.png"
#define ICON_QUIET "./src/pics/quiet.png"
#define ICON_NOT_OPEN "./pics/not_open.png"
#define ICON_NOT_LOOKING "./pics/not_looking.png"
#define ICON_NOT_QUIET "./src/pics/not_quiet.png"		
#define ICON_REFRESH_PLAYERS "./pics/refresh_players.png"   //added eb 6
#define ICON_REFRESH_GAMES "./pics/refresh_games.png"       //end add eb 6
#define ICON_NAV_INTERSECTION "./pics/navIntersection.png"       //SL added eb 11
#define ICON_COMPUTER_PLAY "./pics/computerplay.png"       //SL added eb 12

#endif

#endif

==> qgo_1.0.4-r2.orig.tar.gz: qgo-1.0.4/src/icons.h <==
/*
 * icons.h
 */

#ifndef ICONS_H
#define ICONS_H

#define USE_XPM  
//#undef USE_XPM
#define SEEK_ANIMATION "./pics/seeking.gif"

#ifdef USE_XPM
#define WOOD_PIC "./pics/wood.xpm"
//#define WOOD2_PIC "./pics/wood2.xpm"
//#define WOOD3_PIC "./pics/wood3.xpm"
//#define WOOD4_PIC "./pics/wood4.xpm"
//#define WOOD5_PIC "./pics/wood5.xpm"
#define TABLE_PIC "./pics/table.xpm"
#define ICON_PREFS "./pics/package_settings.xpm"
#define ICON_GAMEINFO "./pics/idea.xpm"
#define ICON_TELNET "./pics/openterm.xpm"
#define ICON_EXIT "./pics/exit.xpm"
#define ICON_FILENEWBOARD "./pics/newboard.xpm"
#define ICON_FILENEW "./pics/filenew.xpm"
#define ICON_FILEOPEN "./pics/fileopen.xpm"
#define ICON_FILESAVE "./pics/filesave.xpm"
#define ICON_FILESAVEAS "./pics/filesaveas.xpm"
#define ICON_TRANSFORM "./pics/transform.xpm"
#define ICON_CHARSET "./pics/charset.xpm"
#define ICON_RIGHTARROW "./pics/1rightarrow.xpm"
#define ICON_LEFTARROW "./pics/1leftarrow.xpm"
#define ICON_RIGHTCOMMENT "./pics/1rightcomment.xpm"        //added eb 2
#define ICON_LEFTCOMMENT "./pics/1leftcomment.xpm"          // end add eb 2
#define ICON_TWO_RIGHTARROW "./pics/2rightarrow.xpm"
#define ICON_TWO_LEFTARROW "./pics/2leftarrow.xpm"
#define ICON_NEXT_VAR "./pics/down.xpm"
#define ICON_PREV_VAR "./pics/up.xpm"
#define ICON_MAIN_BRANCH "./pics/start.xpm"
#define ICON_START_VAR "./pics/top.xpm"
#define ICON_NEXT_BRANCH "./pics/bottom.xpm"
#define ICON_AUTOPLAY "./pics/player_pause.xpm"
#define ICON_CUT "./pics/editcut.xpm"
#define ICON_PASTE "./pics/editpaste.xpm"
#define ICON_DELETE "./pics/editdelete.xpm"
#define ICON_INCREASE_SIZE "./pics/viewmag+.xpm"
#define ICON_DECREASE_SIZE "./pics/viewmag-.xpm"
#define ICON_FULLSCREEN "./pics/window_fullscreen.xpm"
#define ICON_WHATSTHIS "./pics/contexthelp.xpm"
#define ICON_MANUAL "./pics/help.xpm"
#define ICON_HOME "./pics/gohome.xpm"
#define ICON_APPICON "./pics/Bowl.xpm"
#define ICON_NODE_BLACK "./pics/node_black.xpm"
#define ICON_NODE_WHITE "./pics/node_white.xpm"
#define ALT_GHOST_BLACK "./pics/alt_ghost_black.xpm"
#define ALT_GHOST_WHITE "./pics/alt_ghost_white.xpm"
#define ICON_CONNECTED "./pics/connected.xpm"             
#define ICON_DISCONNECTED "./pics/connect_no.xpm"         
#define ICON_OPEN "./pics/open.xpm"			
#define ICON_LOOKING "./pics/looking.xpm"
#define ICON_QUIET "./pics/quiet.xpm"
#define ICON_NOT_OPEN "./pics/not_open.xpm"
#define ICON_NOT_LOOKING "./pics/not_looking.xpm"
#define ICON_NOT_QUIET "./pics/not_quiet.xpm"
#define ICON_REFRESH_PLAYERS "./pics/refresh_players.xpm"   
#define ICON_REFRESH_GAMES "./pics/refresh_games.xpm"       
#define ICON_NAV_INTERSECTION "./pics/navIntersection.xpm"   
#define ICON_COMPUTER_PLAY "./pics/computerplay.xpm"       


#else 
#define WOOD_PIC "./pics/wood.png"
//#define WOOD2_PIC "./pics/wood2.png"
//#define WOOD3_PIC "./pics/wood3.png"
//#define WOOD4_PIC "./pics/wood4.png"
//#define WOOD5_PIC "./pics/wood5.png"
#define TABLE_PIC "./pics/table.png"
#define ICON_PREFS "./pics/package_settings.png"
#define ICON_GAMEINFO "./pics/idea.png"
#define ICON_TELNET "./pics/openterm.png"
#define ICON_EXIT "./pics/exit.png"
#define ICON_FILENEWBOARD "./pics/newboard.png"
#define ICON_FILENEW "./pics/filenew.png"
#define ICON_FILEOPEN "./pics/fileopen.png"
#define ICON_FILESAVE "./pics/filesave.png"
#define ICON_FILESAVEAS "./pics/filesaveas.png"
#define ICON_TRANSFORM "./pics/transform.png"
#define ICON_CHARSET "./pics/charset.png"
#define ICON_RIGHTARROW "./pics/1rightarrow.png"
#define ICON_LEFTARROW "./pics/1leftarrow.png"
#define ICON_RIGHTCOMMENT "./pics/1rightcomment.png"        
#define ICON_LEFTCOMMENT "./pics/1leftcomment.png"         
#define ICON_TWO_RIGHTARROW "./pics/2rightarrow.png"
#define ICON_TWO_LEFTARROW "./pics/2leftarrow.png"
#define ICON_NEXT_VAR "./pics/down.png"
#define ICON_PREV_VAR "./pics/up.png"
#define ICON_MAIN_BRANCH "./pics/start.png"
#define ICON_START_VAR "./pics/top.png"
#define ICON_NEXT_BRANCH "./pics/bottom.png"
#define ICON_AUTOPLAY "./pics/player_pause.png"
#define ICON_CUT "./pics/editcut.png"
#define ICON_PASTE "./pics/editpaste.png"
#define ICON_DELETE "./pics/editdelete.png"
#define ICON_INCREASE_SIZE "./pics/viewmag+.png"
#define ICON_DECREASE_SIZE "./pics/viewmag-.png"
#define ICON_FULLSCREEN "./pics/window_fullscreen.png"
#define ICON_WHATSTHIS "./pics/contexthelp.png"
#define ICON_MANUAL "./pics/help.png"
#define ICON_HOME "./pics/gohome.png"
#define ICON_APPICON "./pics/Bowl.png"
#define ICON_NODE_BLACK "./pics/node_black.png"
#define ICON_NODE_WHITE "./pics/node_white.png"
#define ALT_GHOST_BLACK "./pics/alt_ghost_black.png"
#define ALT_GHOST_WHITE "./pics/alt_ghost_white.png"
#define ICON_CONNECTED "./pics/connected.png"             
#define ICON_DISCONNECTED "./pics/connect_no.png"         
#define ICON_OPEN "./pics/open.png"			
#define ICON_LOOKING "./pics/looking.png"
#define ICON_QUIET "./src/pics/quiet.png"
#define ICON_NOT_OPEN "./pics/not_open.png"
#define ICON_NOT_LOOKING "./pics/not_looking.png"
#define ICON_NOT_QUIET "./src/pics/not_quiet.png"		
#define ICON_REFRESH_PLAYERS "./pics/refresh_players.png"   //added eb 6
#define ICON_REFRESH_GAMES "./pics/refresh_games.png"       //end add eb 6
#define ICON_NAV_INTERSECTION "./pics/navIntersection.png"       //SL added eb 11
#define ICON_COMPUTER_PLAY "./pics/computerplay.png"       //SL added eb 12

#endif

#endif
